/*       _        ___
    /\ / /___    / _ \ /\ /\  _ ___
   / // // _ \  / // // // // // _ \
  / // // // / / ___// // // // // /
  \___//_//_/ /_/   /_/ \___/ \_  /
                             \___/

  Copyright (c) 2006, 2007 CompuNach
  Released under the GNU GPL 2.0 or any later version, Copyleft @ 2006
  
  Note: You should have received a copy of the GNU General Public License along
    with this program; if not, visit fsf.org, or write to the Free Software
    Foundation Inc, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  
  Visit the website:
     unplug.mozdev.org
  
  
  THIS FILE contains the rules for working out where videos are from the urls it
  gathers.
  
  Note that it does not contain information about where KeepVid, VideoDownloader, etc
  work - that is kept in unplug_extern.js
  
  First cn_unplug_special_site is called, which checks the URL of the current page.
  
  Next the <embed> and <object> tags are searched. This is fairly automatic, attributes
  and parameters named "src", etc are added to the list.
  
  Next the <script> tags are searched using the cn_unplug_javastar and cn_unplug_javasoup
  functions.
  
  Finally <a> links are searched using cn_unplug_alink.
  
  
  Once the list is complete, the list itself is scanned for media (this is only done
  once). This uses the function cn_unplug_special_url. For example, links like
  www.a.tld/player.swf?video=video.flv may be found in an <embed>, so
  cn_unplug_special_url will add www.a.tld/video.flv to the list.
  
  
  Anything found is placed on the list using cn_unplug_a, which works like this:
    cn_unplug_a(
      list,             The "list" variable (this is passed into each function)
      route,            An identification mark for how the link was found (for
                          debugging only).
      url,              The URL of the media to add to the list
      media_type,       Pick a value from cn_unplug_me_media, cn_unplug_me_flv, etc
                          Full list shown in unplug.js
      mime,             The mime type if applicable. eg text/xml -- just use "" normally
      notes,            Big blue text under link, eg "guessed link" or something.
      detail,           Little gray text under the link, eg "label" for <A>label</A>
                          links.
      flashvars         Flashvars data -- just use "" normally
    );
  
*/

/**************** DO SCAN *************/

function cn_unplug_scan2(list, thiswin, fullsearch){
   var f = thiswin.frames;
   for (var i = 0; i < f.length; i++) {
      if (f[i].window){
         cn_unplug_scan2(list, f[i].window, fullsearch);
      }
   }
   if (thiswin.document)
      cn_unplug_scan(list, thiswin.document, fullsearch);
}

function cn_unplug_scan(list, doc, fullsearch){
   var els;
   var itemcount = 0;
   
   /* is results window */
   if (doc.getElementById("cn_photobooth")){
      return;
   }
   
   /* scan site url */
   cn_unplug_special_site(doc, list);
   
   /* scan contents */
   try {
      els = doc.getElementsByTagName("EMBED");
      for (var i =0; i < els.length; i++){
         cn_unplug_aqua(doc, els[i], "embed", list);
      }
      els = doc.getElementsByTagName("OBJECT");
      for (var i =0; i < els.length; i++){
         cn_unplug_aqua(doc, els[i], "object", list);
      }
      els = doc.getElementsByTagName("PARAM");
      for (var i =0; i < els.length; i++){
         cn_unplug_aqua(doc, els[i], "param", list);
      }
      els = doc.getElementsByTagName("BGSOUND");
      for (var i =0; i < els.length; i++){
         cn_unplug_aqua(doc, els[i], "bgsound", list);
      }
      
      els = doc.getElementsByTagName("IFRAME");
      for (var i =0; i < els.length; i++){
//         cn_unplug_scan2(list, els[i].contentWindow, fullsearch); /* CRASH! */
         cn_unplug_aqua(doc, els[i], "iframe", list);
      }
      
      els = doc.getElementsByTagName("SCRIPT");
      for (var i =0; i < els.length; i++){
         cn_unplug_javastar(doc, els[i], list);
      }
      
      els = doc.getElementsByTagName("DIV");
      for (var i =0; i < els.length; i++){
         if (els[i].className == "cn_unplug_hiddiv"){
            cn_unplug_flashblockdecode(doc, els[i].innerHTML, list);
         }
      }
      
      if (cn_unplug_pref("search_links") && fullsearch){
         els = doc.getElementsByTagName("A");
         for (var i =0; i < els.length; i++){
            cn_unplug_alink(list, els[i], "hyperlink", doc);
            if (i >= 1000) {
               cn_unplug_err("scan (page scan)", "Searching " + els.length + " hyperlinks timed out after "+i);
               break;
            }
         }
         els = doc.getElementsByTagName("AREA");
         for (var i =0; i < els.length; i++){
            cn_unplug_alink(list, els[i], "hyperlink-area", doc);
         }
      }
      
   } catch (e){
      cn_unplug_err("scan (page scan)", e);
   }
   
   //some NoScript shit - note FLASHVARS are not obtained from NoScript: FIXME, FIXME, FIXME dammit, FIXME!
   try {
      if (noscriptOverlay){
         els = doc.getElementsByTagName("div");
         for (var i =0; i < els.length; i++){
            var div = els[i];
            const ns = noscriptOverlay.ns;
            const lm = ns.lookupMethod;
            const extras = ns.getPluginExtras(div);
            
            if (extras && extras.url){
               cn_unplug_a(list, "noscript.generic", cn_unplug_url(doc, extras.url), cn_unplug_me_unknown, extras.mime, "", "", "");
               
               //not working:
               if (div._noScriptRemovedObject){
                  //n.flashvars = ...
                  // or rather perform direct doobry on object, if only I could get to it
                  //alert(div._noScriptRemovedObject);
               }
            }
         }
      }
   } catch(e) {
      // DO NOT COMPLAIN, it's all ok really
   }
}

function cn_unplug_flashblockdecode(doc, tx, list){
   var txs = tx.split("?");
   var cflvar = "";
   var csrc = "";
   for (var i=0; i < txs.length; i++){
      var r = txs[i].substring(txs[i].indexOf("=")+1, txs[i].length);
      var q = txs[i].toLowerCase();
      if (r.length > 0) {
         if (q.indexOf("src=") >= 0 || q.indexOf("movie=") >= 0 || q.indexOf("filename=") >= 0){
            if (csrc == "") csrc = r;
         }
         if (q.indexOf("flashvar=") >= 0){
            if (cflvar == "") cflvar = r;
         }
      }
   }
   cn_unplug_a(list, "flash-bindings", cn_unplug_url(doc, unescape(csrc)), cn_unplug_me_unknown, "", "", "", unescape(cflvar));
}

function cn_unplug_aqua(doc, els, extra, list) {
   if (!els || !els.attributes) return;
   for (var i = 0; i < els.attributes.length; i++){
      switch (els.attributes[i].name.toLowerCase()) {
         case "src":
         case "url":
         case "href":
         case "filename":
            cn_unplug_a(list, extra + ".aqua-default-filter{" + els.attributes[i].name + "}", cn_unplug_url(doc, els.attributes[i].value), cn_unplug_me_unknown, "", "", "", els.getAttribute("flashvars"));
            break;
         case "name":
            /* eg. for PARAM */
            /* match name="...." to one of the following: */
            if (els.attributes[i].value.toLowerCase().indexOf("file") >= 0
             || els.attributes[i].value.toLowerCase().indexOf("href") >= 0
             || els.attributes[i].value.toLowerCase().indexOf("url") >= 0
             || els.attributes[i].value.toLowerCase().indexOf("src") >= 0
             || els.attributes[i].value.toLowerCase().indexOf("movie") >= 0
            ){
               /* check other attribs for value="..." */
               for (var j = 0; j < els.attributes.length; j++){
                  if (els.attributes[j].name.toLowerCase().indexOf("value") >= 0
                  && i != j
                  && els.attributes[j].value) {
                     cn_unplug_a(list, extra + ".aqua-pair-filter{" + els.attributes[i].value + ".value}", cn_unplug_url(doc, els.attributes[j].value), cn_unplug_me_unknown, "", "", "", "");

                  }
               }
            }
            break;
      }
   }
}

function cn_unplug_javalink(tx, list, els, url){
   
   // CNN.COM
   if (tx.indexOf("cnnVideo") >= 0){
      var u = tx.substring(tx.indexOf(","), tx.length);
      u= u.substring(u.indexOf("'")+1, u.length);
      u= u.substring(0, u.indexOf("'"));
      if (u.indexOf(".cnn") >= 0) {
         cn_unplug_a(list, "javalink.cnnvideo", "http://dynamic.cnn.com/apps/tp" + u + "/video.ws.asx" /* ?NGUserID=false&adDEmas=false */, cn_unplug_me_textplay, "#textplay", "", "", "");
      }
   }
   
   //ungrounded.net
   if (tx.indexOf("OpenPortalContentWin")>=0){
      var u = tx.substring(tx.indexOf("(")+1, tx.indexOf(")"));
      u = u.replace(/, /, ",");
      var ux = u.split(",");
      cn_unplug_a(list, "javalink.ungrounded", "http://uploads.ungrounded.net/" + ux[0].substring(0, ux[0].length - 3) + "000/" + ux[3].replace(/\"/, ""), cn_unplug_me_swf, "#swf", "", ux[4], "");
   }
}

function cn_unplug_alink(list, els, zone, doc){
   for (var j = 0; j < els.attributes.length; j++){
      if (els.attributes[j].name.toLowerCase() == "href") {
      
         var loci = els.attributes[j].value;
         
         if (loci.indexOf("javascript:") >= 0){
         
            cn_unplug_javalink(loci, list, els, doc.URL);
            
         } else {
            
            var inx = ""
            if (els.innerHTML && els.innerHTML != "")
               inx += els.innerHTML + " ";
            if (els.title && els.title != "")
               inx += els.title + " ";
            
            //main in link
            var ue = loci;
            if (ue.indexOf("?")>=0) ue = ue.substring(0, ue.indexOf("?"));
            if (cn_unplug_ftype(ue, "ext") >= 0) {
               if (ue.indexOf("Image:") > 0)
                  cn_unplug_a(list, zone + ".alink.href.wikiinfo", cn_unplug_url(doc, loci), cn_unplug_me_noscore, "", "Information page", inx, "");
               else
                  cn_unplug_a(list, zone + ".alink.href", cn_unplug_url(doc, loci), cn_unplug_me_link, "", "", inx, "");
            }
            
            //searchstring
            ue = loci;
            if (ue.indexOf("?")>=0) {
               ue = ue.substring(ue.indexOf("?")+1, ue.length);
               var aj = ue.split(/&/);
               for (var q = 0; q < aj.length; q++) {
                  aj[q] = aj[q].substring(aj[q].indexOf("=")+1, aj[q].length);
                  if (aj[q].indexOf("://")>=0 && cn_unplug_ftype(aj[q], "ext") >= 0){
                     cn_unplug_a(list, zone + ".alink.generic-search-term", cn_unplug_url(doc, aj[q]), cn_unplug_me_link, "", "", inx, "");
                  }
               }
               
            }
            
            // alluc/youtube
            {
               var rgyou = /youtube\.com\/v\/(.+)/ig;
               var rr;
               while (rr = rgyou.exec(loci)){
                  var id=rr[1];
                  cn_unplug_a(list, zone+".link-youtube", "http://www.youtube.com/watch?v=" + id, cn_unplug_me_data, "#xml", "", "", "");
               }
            }
   
            //misc rules
            ue = loci;
            if (ue.search(/media\.revver\.com.*\/download/i) >= 0) {
               cn_unplug_a(list, zone + ".alink.href.miscrules", cn_unplug_url(doc, ue), cn_unplug_me_link, "", "", inx, "");
            }
         }
            
         
         
      }
   }
}


/********************* WEBSITE URL **********************/

function cn_unplug_special_site(doc, list){
   // From website name
   if (!doc || !doc.URL) return;
   
   var url = String(doc.URL);
   var ip = "site{ " + url + " }.";
   var s = ip;
   
   /*
   For compatability with special url (SURL) below, switch to url/ip schema
   */
   
   // YAHOO MOVIES
   if (doc.URL.indexOf("movies.yahoo.com") >= 0){
      var u = doc.URL + "&";
      var rx_id = /(?:id|f)=([0-9]+)&/ig;
      var rx_id_res = rx_id.exec(u);
      if (rx_id_res) {
         var rx_p = /p\.([0-9]+)-([0-9]+),/gi;
         var rx_p_res;
         var timeout = 20;
         while (rx_p_res = rx_p.exec(u)){
            cn_unplug_a(list, s+"yahoo-playlist", "http://playlist.yahoo.com/makeplaylist.dll?id=" + rx_p_res[1] + "&segment=" + rx_p_res[2] + "&s=" + rx_id_res[1] + "&ru=y&type=c&ext=1", cn_unplug_me_textplay, "", "", "", "");
            //failsafe
            if (--timeout < 1) throw "Yahoo timed out";
         }
      }
   }
   
   // IMEEM.COM
   if (url.indexOf("imeem.com") >= 0 && url.indexOf("playlist/") >= 0) {
      var id = url.substring(url.indexOf("playlist/")+"playlist/".length, url.length);
      
      if (id.indexOf("/") > 0)
         id = id.substring(0, id.indexOf("/"));
      if (id.indexOf("?") > 0)
         id = id.substring(0, id.indexOf("?"));
      if (id.indexOf("#") > 0)
         id = id.substring(0, id.indexOf("#"));
      
      if (id.length > 0)
         cn_unplug_a(list, s+"imeem", "http://www.imeem.com/playlist.ashx?v=3&p=" + id, cn_unplug_me_data, "", "", "", "");
   }
   
   //YAHOO
   if (doc.URL.indexOf("video.yahoo.com") >= 0){
      var u = doc.URL;
      u = u.substring(u.indexOf("vid="), u.indexOf("&cache"));
      u = u.substring(u.indexOf(".")+1, u.length);
      if (u && u.length > 1){
         cn_unplug_a(list, s+"yahoo-vidll", "http://playlist.yahoo.com/makeplaylist.dll?sdm=web&sid=28899441&ticket=0&s=0&start=0&end=&afr=0&nodeid="+u+"&trk=&d=293&tz=&pg=&authid=&sl=293&so=", cn_unplug_me_textplay, "", "", "", "");
      }
   }
   
   //VEOH
   if (url.indexOf("veoh.com/videos/") >= 0){
      var id = url.substring(url.indexOf("videos/") + "videos/".length, url.length);
      if (id.indexOf("/") > 0)
         id = id.substring(0, id.indexOf("/"));
      if (id.indexOf("?") > 0)
         id = id.substring(0, id.indexOf("?"));
      if (id.indexOf("#") > 0)
         id = id.substring(0, id.indexOf("#"));
      cn_unplug_a(list, s+"veoh", "http://www.veoh.com/rest/video/" + id + "/details", cn_unplug_me_data, "", "", "", "");
   }
   
   // VIDIAC
   if (url.indexOf("vidiac.com") >= 0 && url.indexOf("video") >= 0){
      var id = url.substring(url.lastIndexOf("/") + 1, url.lastIndexOf("."));
      cn_unplug_a(list, s+"vidiac", "http://209.9.234.31/flv2/" + id + "-.flv", cn_unplug_me_flv, "", "", "", "");
   }
   
   
   //BADJO HENTAI
   if (doc.URL.indexOf("badjojo.com") >= 0 && doc.getElementsByName("clickd").length > 0) {
      doc.getElementsByName("clickd").item(0).disabled = false;
   }
   
   
   //STREETFIRE / FREEVIDEOBLOG
   if (doc.URL.indexOf("videos.streetfire.net/video/") >= 0 || doc.URL.indexOf("video.freevideoblog.com/video/") >= 0){
      var u = doc.URL.substring(doc.URL.lastIndexOf("/")+1, doc.URL.lastIndexOf("."));
      cn_unplug_a(list, s+"209-9-234-5", "http://209.9.234.5/flv/" + u + "-.flv", cn_unplug_me_flv, "", "", "", "");
   }
   
   
   // OUOU
   if (url.indexOf("ouou.com") >= 0 && url.indexOf("v_") >= 0) {
      var id = url.substring(url.indexOf("v_")+2, url.indexOf(".htm"));
      if (id != "")
         cn_unplug_a(list, s+"ouou", "post://stat.ouou.com/playservlet?id=" + id + " ##post:" + escape("<id>" + id + "</id>") + " ##type:" + escape("text/xml;charset=utf8") + " ##cookie:" + escape("Cookie: h_quicklistvar=0|0|0|-1|-1"), cn_unplug_me_data, "", "", "", "");
   }
   
   
   
   // AOL (NOTE : TESTING ONLY)
   if (doc.URL.indexOf("video.aol.com") >= 0){
      var asst = "";
      
      if (doc.URL.indexOf("pmmsid=") >= 0) {
         var pmmsid = doc.URL;
         pmmsid = pmmsid.substring(pmmsid.indexOf("pmmsid=")+"pmmsid=".length, pmmsid.length);
         if (pmmsid.indexOf("&") > 0)
            pmmsid = pmmsid.substring(0, pmmsid.indexOf("&"));
         
         asst = "video:asset:pmms:" + pmmsid;
      }
      
      if (asst.length > 0)
         cn_unplug_a(list, s+"aol-pmmsid", "http://videoapi.aolcdn.com/API/platform/jsondispatch.adp/IMetadataDescribe?ClientCap=pp_us.video.aol.com_4.0&linkDomain=http://us.video.aol.com&RefID=" + asst, cn_unplug_me_data, "Testing-only link", "", "", "");
   }
   
   // AOL PLAYLIST (NOTE: TESTING ONLY)
   if (doc.URL.indexOf("video.aol.com") >= 0){
      var pls = cn_unplug_urlget(doc.URL, "pls");
      var startid = cn_unplug_urlget(doc.URL, "startid");
      
      if (pls.length > 0 && startid.length > 0) 
         cn_unplug_a(list, s+"aol-pmmsid",
            "http://us.video.aol.com/playlist.adp?fmt=js&pls=" + pls + "&pc=general&type=wmv&sfp=" + "us.aol.video.2500_" + "&startid=" + startid,
            cn_unplug_me_data, "Testing-only link", "", "", "");
   }
   
   // YOQOO.COM
   if (url.indexOf("yoqoo.com") >= 0) {
      // grabs from a javascript link
      // but the thing isn't a proper link, so we'll search the whole page!
      var rx = /sendVideoLink[\s]*\([\s]*\'[^\']*\'[\s]*,[\s]*\'([^\']*)\'[\s]*\)/gi;
      while (rr = rx.exec(doc.body.innerHTML)){
         cn_unplug_a(list, "javalink.yoqoo", "http://www.yoqoo.com/player/getFlvPath/fileid/" + rr[1] + "?onData=%5Btype%20Function%5D&%5Fparent=%5Flevel0%2Econtrol%5Fmc", cn_unplug_me_data, "", "", "", "");
      }
   }
   
   // COMEDYCENTRAL
   if (url.indexOf("comedycentral.com") >= 0) {
      var id = cn_unplug_urlget(url, "ml_video");
      if (id.length > 0)
         cn_unplug_a(list, "javalink.comedycentral", "http://www.comedycentral.com/motherload/xml/flv_xml_gen.jhtml?ml_video=" + id + "&hiLoPref=hi", cn_unplug_me_data, "", "Found from website URL. Video location in playlist below.", "", "");
   }
   
   // GRINVI
   if (doc.URL.indexOf("grinvi.greenshines.com") >= 0){
      if (doc.URL.indexOf("id=") >= 0) {
         var num = doc.URL;
         num = num.substring(num.indexOf("id=")+3, num.length);
         if (num.indexOf("&") > 0) num = num.substring(0, num.indexOf("&"));
         cn_unplug_a(list, s+"grinvi", "http://grinvi.greenshines.com/video/" + num + ".flv", cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   
   // XTUBE
   if (url.indexOf("xtube.com") >= 0) {
      var a = cn_unplug_urlget(url, "a");
      var cl = cn_unplug_urlget(url, "cl");
      if (a.length > 0 && cl.length > 0)
         cn_unplug_a(list, s+"xtube", "http://p8.xtube.com/videos/" + a + "/" + cl + ".flv", cn_unplug_me_flv, "", "", "", "");
   }
   
   //PORNOTUBE
   if (doc.URL.indexOf("pornotube.com") >= 0){
      var id = doc.URL;
      if (id.indexOf("m=") >= 0){
         id = id.substring(id.indexOf("m=")+"m=".length, id.length);
         if (id.indexOf("&") > 0)
            id = id.substring(0, id.indexOf("&"));
         
         var db = String(doc.body.innerHTML);
         var reg = /thumbnails\/video\/([\d]*)\/[\d]*.jpg/gi
         var regr;
         while (regr = reg.exec(db)) {
            cn_unplug_a(list, s+"pornotube", "http://video.pornotube.com/" + regr[1] + "/" + id + ".flv", cn_unplug_me_flv, "", "", "", "");
         }
      }
   }
   
   //ADULTVIDEOPLAYER
   if (doc.URL.indexOf("adultvideoplayer.com/main.php") >= 0){
      var u = doc.URL;
      var reg = /\?(?:.*&)?MODE=PLAY&(?:.*&)?(?:VIDEO)?ID=([0-9A-F]+)&(?:.*&)?SESSIONID=([0-9A-F]+)/ig;
      var rr;
      if (rr = reg.exec(u)) {
         cn_unplug_a(list, s+"adultvp", cn_unplug_url2(u, "stream-flv.php?ID=" + rr[1] + "&SESSIONID=" + rr[2]), cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   //IFILM (2007)
   if (url.indexOf("ifilm.com") >= 0) {
      var reg = /video\/([0-9]+)/gi;
      var rr;
      while (rr = reg.exec(url)) {
         var id = rr[1];
         /*
         var post = "ifilm_session={ifilm_session}&refsite=default&Referrer=/video/" + id  + "&sessionId=ANONYMOUS&bandwidth=300&mediaType=flv&impressionType=18&ifilmId=" + id;
         cn_unplug_a(list, s+"ifilm-post", "post://www.ifilm.com/player/impression ##form:" + escape(post), cn_unplug_me_data, "", "", "", "");
         */
         cn_unplug_a(list, s+"ifilm-post", "http://origin.www.ifilm.com/flash/getURL.jsp?productId=" + rr[1] + "&cacheBuster=0", cn_unplug_me_data, "", "", "", "");
      }
   }
   
   //BOLT
   if (url.indexOf("bolt.com") >= 0) {
      var id = url.substring(url.lastIndexOf("/")+1, url.length);
      cn_unplug_a(list, s+"bolt-2", "http://utils.bolt.com/portfolio/video/genXml.bt?contentId=" + id, cn_unplug_me_data, "", "", "", "");
   }
   
   //JIBJAB
   if (url.indexOf("jibjab.com") > 0) {
      var reg = /id\/([0-9]+)\/.+\/([0-9])+/gi;
      var rr;
      while (rr = reg.exec(url)) {
         cn_unplug_a(list, s+"jibjab", "http://llnw.jibjab.com/feeds/player/" + rr[2] + "/" + rr[1], cn_unplug_me_data, "", "", "", "");
      }
   }
   
   //NEWS.NTV.RU
   if (doc.URL.indexOf("news.ntv.ru") >= 0 && doc.URL.indexOf("/video") >= 0) {
      var id = doc.URL;
      id = id.substring(id.indexOf(".ru/") + ".ru/".length, id.indexOf("/video"));
      if (id.length > 0)
         cn_unplug_a(list, s+"ntv_ru", "http://news.ntv.ru/news/newsInfo.jsp?id=" + id, cn_unplug_me_data, "", "", "", "");
   }
   
   //COLLEGEHUMOR
   //collegehumor.com/video:1728017/context/popular
   if (doc.URL.indexOf("collegehumor.com") >= 0 && doc.URL.indexOf("video:") >= 0){
      var id=doc.URL;
      id = id.substring(id.indexOf("video:") + "video:".length, id.length);
      if (id.indexOf("/") >= 0)
         id = id.substring(0, id.indexOf("/"));
      if (id.length > 0) {
         cn_unplug_a(list, s+"collegehumor-ajax", "http://www.collegehumor.com/moogaloop/ch6.ml.get_clip_details.php?clip_id=" + id, cn_unplug_me_data, "", "", "", "");
      }
   }
   
   //TAGWORLD
   if (doc.URL.indexOf("tagworld.com") >= 0){
      var tf = doc.getElementById("copytext");
      if (tf) {
         var th = tf.innerHTML;
         th = th.substring(th.indexOf("videoURL=")+"videoURL=".length, th.length);
         th = th.substring(0, th.indexOf("&"));
         cn_unplug_a(list, s+"tagwiorld", "http://stream.tagworld.com/"+th, cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   //MYSPACE (newer version for 9 or 10 digit links)
   if (doc.URL.indexOf("myspace.com") >= 0 && doc.URL.toLowerCase().indexOf("videoid") >= 0){
      var num = doc.URL.substring(doc.URL.toLowerCase().indexOf("videoid="), doc.URL.length);
      num = num.substring(num.indexOf("=")+1, num.length);
      if (num.indexOf("&") >= 0) num = num.substring(0, num.indexOf("&"));
      var num_nozero = num;
      while (num.length < 12) num = "0"+num;
      var eu = "http://content.movies.myspace.com/" +
         num.substring(0,7) + '/' + num.charAt(11) +
         num.charAt(10) + '/' + num.charAt(9) +
         num.charAt(8) + '/' + num_nozero + '.flv';
      cn_unplug_a(list, s+"myspace-any", eu, cn_unplug_me_flv, "", "", "", "");
   }
   
   // GOFISH.COM
   if (url.indexOf("gofish.com") >= 0) {
      var id = cn_unplug_urlget(url, "gfid");
      cn_unplug_a(list, ip+"gofish", "http://www.gofish.com/getGFX2.gfp?gfid=" + id + "&getAd=true&location=thplayer", cn_unplug_me_data, "", "", "", "");
   }
   
   //FRANCE5.FR
   if (url.indexOf("france5.fr") >= 0 && doc.body) {
      var reg = /url=(mms%3A%2F%2F[^"&]+)["&]/ig;
      var rr;
      while (rr = reg.exec(String(doc.body.innerHTML))) {
         cn_unplug_a(list, ip+"france5", unescape(rr[1]), cn_unplug_me_media, "", "", "", "");
      }
   }
   
   //bharatstudent/Campus TV
   if (url.indexOf("bharatstudent.com") >= 0) {
      var reg = /"..\/([^"]*)0000.png"/gi;
      var rr;
      while (rr = reg.exec(String(doc.body.innerHTML))) {
         cn_unplug_a(list, ip+"bharatstudent", "http://videos.bharatstudent.com/" + rr[1] + ".flv", cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   //FLURL.COM
   if (url.indexOf("flurl.com/item") >= 0){
      var id = url.substring(url.lastIndexOf("_")+1, url.length);
      cn_unplug_a(list, ip+"flurl-php", "http://www.flurl.com/flash_player_info.php?id=" + id, cn_unplug_me_data, "", "", "", "");
   }
   
   
   //MYSPACE MUSIC
   if (false 
    && url.indexOf("myspace.com") >= 0 && doc.getElementById("mp3player")){
      /* var /friendID=([0-9]+)["&]/ takes forever, so try specific link */
      /* "http://messaging.myspace.com/index.cfm?fuseaction=mail.message&friendID= [ID] &MyToken= ... " */
      var reg = /myspace\.com\/index\.cfm\?[^"']*&friendID\=([0-9]+)["'&]/gi;
      var s = String(doc.body.innerHTML);
      var rr;
      while (rr = reg.exec(s)){
         cn_unplug_a(list, ip+"myspace-mp3xml", "http://mediaservices.myspace.com/services/media/musicplayerxml.ashx?b="+rr[1], cn_unplug_me_data, "", "", "", "");
      }
   }
   
   //METACAFE
   if (doc.URL.indexOf("metacafe.com/watch/") >= 0){
      var u = doc.URL;
      u = u.substring(u.indexOf("watch/")+"watch/".length, u.length);
      u = u.substring(0, u.indexOf("/"));
      if (u.length > 0)
         cn_unplug_a(list, s+"metacafe-embed-xml", "http://www.metacafe.com/fplayer.php?itemID=" + u + "&fs=n&t=embedded", cn_unplug_me_data, "", "", "", "");
   }
   
   //SUPERDELUXE
   if (url.indexOf("superdeluxe.com") >= 0 && url.indexOf("contentDetail.do") >= 0) {
      var id = cn_unplug_urlget(url, "id");
      cn_unplug_a(list, s+"superdeluxe", "http://www.superdeluxe.com/sd/contentXml.do?id=" + id, cn_unplug_me_data, "", "", "", "");
   }
   
   //EVTV FIXME BROKEN!!
   if (doc.URL.indexOf("evtv1.com") >= 0 && doc.URL.indexOf("itemnum=")) {
      var id = doc.URL;
      id = id.substring(id.indexOf("itemnum=")+"itemnum=".length, id.length);
      if (id.indexOf("&") >= 0)
         id = id.substring(0, id.indexOf("&"));
      if (id.length > 0)
         cn_unplug_a(list, s+"evtv1", "http://www.evtv1.com/include/flash/getcliplist.aspx?itemnum="+id, cn_unplug_me_textplay, "", "", "", "");
   }
   
   
   //WEBCAMERON
   if (doc.URL.indexOf("webcameron.org.uk") >= 0 && doc.URL.indexOf("video") >= 0){
      var u = doc.URL.toLowerCase();
      var num = "";
      
      if (u.indexOf("library") >= 0)
         num = u.substring(u.indexOf("-")+1, u.length);
      if (u.indexOf("id=") >= 0)
         num = u.substring(u.indexOf("id=")+3, u.length);
      
      if (num.indexOf("&") >= 0)
         num = num.substring(0, num.indexOf("&"));
      if (num.length > 0)
         cn_unplug_a(list, s+"webcammeron", "http://www.webcameron.org.uk/content/video/"+num+".flv", cn_unplug_me_flv, "", "", "", "");
   }
   
   //MUVEEMIX.COM
   if (url.indexOf("muveemix.com/player.php/") >= 0){
      var id = url.substring(url.indexOf("player.php/") + "player.php/".length, url.length);
      if (id.indexOf("-") >= 0)
         id = id.substring(0, id.indexOf("-"));
      cn_unplug_a(list, s+"muveemix", "http://www.muveemix.com/media/muvees/" + id + ".flv", cn_unplug_me_flv, "#flv", "", "", "");
   }
   
   // MAIL.RU
   if (url.indexOf("video.mail.ru") >= 0) {
      var reg = /^(.*)\/([0-9]+)\.html/gi;
      var rr;
      while ( rr = reg.exec(url) ) {
         cn_unplug_a(list, s+"mail-ru", rr[1] + "/v-" + rr[2] + ".flv", cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   //FOX NEWS
   if (doc.URL.indexOf("foxnews.com") >= 0 && doc.URL.indexOf("player") >= 0) {
      swfname = doc.URL.substring(doc.URL.indexOf("?") + 1, doc.URL.indexOf("&"));
      if (swfname.length > 0) 
         cn_unplug_a(list, s+"foxnews", "http://media2.foxnews.com/"+swfname+"_300.swf", cn_unplug_me_flv, "#flv", "", "", "");
   }
   
   //ANIMEEPISODES
   /*
   if (doc.URL.search(/(animeepisodes.net|amvspace.com)\/(video|category)\/.\.htm/) >= 0){
      var num = doc.URL;
      num = num.substring(num.lastIndexOf("/")+1, num.indexOf(".htm"));
      if (num.length > 2) {
         //cn_unplug_a(list, s+"animeepisodes", "http://209.9.228.21/flv2/" + num + "-.flv", cn_unplug_me_flv, "", "", "", "");
         cn_unplug_a(list, s+"animeepisodes", "http://209.9.234.2/above?fileid=" + num, cn_unplug_me_textplay, "#asx", "", "", "");
      }
   }
   */
   if (url.indexOf("animeepisodes.net") > 0 && url.lastIndexOf(".htm") > 0){
      var id = url.substring(url.lastIndexOf("/")+1, url.lastIndexOf(".htm"));
      if (id.length > 30) {
         cn_unplug_a(list, s+"animeepisodes-xml", "http://video.animeepisodes.net/playlistbuilder/buildflash.ashx?fileid=" + id + "&viewerid=undefined&t=00000000-0000-0000-0000-000000000000&cid=undefined", cn_unplug_me_data, "#xml", "", "", "");
      }
   }

   
   //LIVEDIGITAL
   if (doc.URL.indexOf("livedigital.com") >= 0 && doc.URL.indexOf("content/") >= 0){
      var a = doc.URL;
      a = a.substring(a.indexOf("content/") + "content/".length, a.length);
      if (a.indexOf("/") > 0)
         a = a.substring(0, a.indexOf("/"));
      cn_unplug_a(list, s+"livedigital", "http://livedigital.com/content/flash_load_content/" + a + "/0/0", cn_unplug_me_textplay, "#asx", "", "", "");
   }
   
   //VSOCIAL NEW (PAGESCAN)
   if (doc.URL.indexOf("vsocial.com") >= 0){
      var db = String(doc.body.innerHTML);
      var reg = /ups\/([0-9a-f]{32})/ig;
      var regr;
      while (regr = reg.exec(db)) {
         cn_unplug_a(list, s+"vsocial-pagescan", "http://static.vsocial.com/varmedia2/vsocial/flv2/" + regr[1] + "_out.flv", cn_unplug_me_flv, "#flv", "", "", "");
      }
   }
   
   // VIMEO
   if (url.indexOf("vimeo.com") >= 0 && url.indexOf("clip") >= 0){
      var id = url.substring(url.indexOf("clip")+"clip".length, url.length);
      if (id.indexOf(":") >= 0)
         id = id.substring(id.indexOf(":")+1, id.length)
      else if (id.indexOf("=") >= 0)
         id = id.substring(id.indexOf("=")+1, id.length)
      if (id.indexOf("/") >= 0)
         id = id.substring(0, id.indexOf("/"))
      if (id.indexOf("?") >= 0)
         id = id.substring(0, id.indexOf("?"))
      if (id.indexOf("#") >= 0)
         id = id.substring(0, id.indexOf("#"))
      if (id.indexOf("&") >= 0)
         id = id.substring(0, id.indexOf("&"))
      if (id.length > 0)
         cn_unplug_a(list, ip+"vimeo", "http://www.vimeo.com/_moogaloop/vimeo.ml.get_clip_details.php?clip_id=" + id + "&width=400&height=300", cn_unplug_me_data, "#xml", "", "", "");
   }
   
   //JUMPCUT
   if (doc.URL.indexOf("jumpcut.com") >= 0 && doc.URL.indexOf("id=") >= 0) {
      cn_unplug_a(list, s+"jumpcut", "http://media.jumpcut.com/media/splicer?mversion=3&master_params="+cn_unplug_urlget(doc.URL, "id"), cn_unplug_me_flv, "#flv", "", "", "");
   }
   
   //GENERIC SEARCH
   var ser = doc.URL.substring(doc.URL.indexOf("?")+1, doc.URL.length);
   if (ser.indexOf("url") >= 0) {
      var lo = ser;
      lo = lo.substring(lo.indexOf("url"), lo.length);
      if (lo.indexOf("=") >= 0) {
         lo = lo.substring(lo.indexOf("=")+1, lo.length);
         if (lo.indexOf("&") > 0) lo = lo.substring(0, lo.indexOf("&"));
         if (doc.URL.indexOf("cnn.com")>=0){
            lo = "http://dynamic.cnn.com/apps/tp" + lo + "/video.ws.asx?NGUserID=false&adDEmas=false";
            /* FIXME - wtf is this doing HERE? */
         } else {
            if (lo.indexOf("%") < 10)
               lo = unescape(lo);
            if (lo.indexOf("://") < 0){
               lo = "http://" + lo;
            }
         }
         cn_unplug_a(list, s+"generic.*", lo, cn_unplug_me_unknown, "", "", "", "");
      }
   }
}



function cn_unplug_is_player(itm){
   itm.media_type = cn_unplug_me_flvplay;
}

/********************** SPECIAL GATHERED URL (SURL) *********************/

function cn_unplug_special_url(doc, list, i){
   var url = list[i].url;
   
   var ip = "list{" + i + ": " + list[i].url + "} .surl.";
   
   // GOOGLE
   if (url.indexOf("video.google.") >= 0){
      if (url.indexOf("videoUrl=") >= 0) {
         cn_unplug_is_player(list[i]);
         cn_unplug_a(list, ip+"google", unescape(url.substring(url.indexOf("videoUrl=")+"videoUrl=".length, url.length)), cn_unplug_me_flv, "", "", list[i].detail, "");
      }
   }

   // VIDILIFE
   if (url.indexOf("http://streaming5.vidilife.com") >= 0){
      cn_unplug_a(list, ip+"vidlife", "mms" + url.substring(4,url.length), cn_unplug_me_playlist, "", "", list[i].detail, "");
   }
   
   // IFILM
/* FIXME UPDATE REQUIRED!
   if (url.indexOf("ifilm.com/efp") >= 0){
      var id = list[i].flashvars;
      id = id.substring(0, id.indexOf("flvBaseClip"));
      id = id.substring(id.indexOf("=") + 1, id.length);
      if (id.indexOf(";")>0) id = id.substring(0, id.indexOf(";"));
      if (id.indexOf("&")>0) id = id.substring(0, id.indexOf("&"));
      
      cn_unplug_is_player(list[i]);
      cn_unplug_ifilm(list, id, "", ip+"ifilm");
   }
*/
   
   // APPLE TRAILERS
   if (url.indexOf("apple.com") >= 0 && url.indexOf(".mov") >= 0) {
      if (url.indexOf("_btn") >= 0){
         
         list[i].media_type = cn_unplug_me_noscore;
         
      } else if (url.indexOf("_h.") >= 0){
      
         var newurl = url.substring(0, url.indexOf("_h.")) + "_h" + url.substring(url.indexOf("_h.") + "_h.".length, url.indexOf(".mov")) + "w.mov";
         
         cn_unplug_is_player(list[i]);
         cn_unplug_a(list, ip+"apple.w", newurl, cn_unplug_me_media, "", "", list[i].detail, "");
         
      } else {
         
         var newurl = url.replace(/_[a-z]?([0-9]+[a-z]?)\.mov/, "_h$1.mov");
         
         cn_unplug_is_player(list[i]);
         cn_unplug_a(list, ip+"apple.p", newurl, cn_unplug_me_media, "", "", list[i].detail, "");
         
      }

   }
   
   
   //REVVER EMBED
   if (url.indexOf("flash.revver.com/player") >= 0) {
      var id = cn_unplug_urlget(String(list[i].flashvars), "mediaId");
      if (id.length > 0) {
         //cn_unplug_a(list, ip+"revver-embed-redir", "http://one.revver.com/watch/" + id, cn_unplug_me_redir, "", "", "", "");
         cn_unplug_a(list, ip+"revver-embed", "http://media.revver.com/qt;download/" + id + ".mov", cn_unplug_me_media, "", "QuickTime", "", "");
      }
   }
   
   // TINYPIC
   if (url.indexOf("video.tinypic.com/player.swf") >= 0){
      var id = cn_unplug_urlget(url, "file");
      if (id.length > 0)
         cn_unplug_a(list, ip+"tinypc-embed", "http://video.tinypic.com/" + id, cn_unplug_me_flv, "", "", "", "");
   }
   
   
   // GOFISh EMBED
   if (url.indexOf("gofish.com/player/fwplayer.swf") >= 0) {
      var gfid = cn_unplug_urlget(list[i].flashvars, "gfid");
      cn_unplug_is_player(list[i]);
      if (gfid != "")
         cn_unplug_a(list, ip+"gofish-embed", "http://www.gofish.com/getGFX2.gfp?gfid=" + gfid + "&getAd=false&location=blog", cn_unplug_me_data, "", "", "", "");
   }
   
   // OUOU
   if (url.indexOf("ouou.swf") >= 0) {
      var id = cn_unplug_urlget(url, "id");
      var part = 0;
      cn_unplug_is_player(list[i]);
      if (id != "")
         cn_unplug_a(list, ip+"ouou-embed", "post://stat.ouou.com/playservlet?id=" + id + "&part=" + part + " ##form:" + escape("<id>" + id + "</id><part>" + part + "</part>"), cn_unplug_me_data, "", "", "", "");
   }
   
   //FLURL
   if (url.indexOf("flurl.com/flvplayer2.swf?video=") >= 0){
      var u = url.substring(url.indexOf("video=") + "video=".length, url.length);
      if (u && u.length > 1){
         cn_unplug_a(list, ip+"flurl-lookup", u, cn_unplug_me_textplay, "", "", "", "");
      }
   }
   
   // TUDOU.COM EMBED
   if (url.indexOf("tudou.com/v/") >= 0){
      var id = url.substring(url.indexOf("tudou.com/v/")+"tudou.com/v/".length, url.length);
      id = cn_unplug_mainurl(id);
      cn_unplug_a(list, ip+"tudou-embed", "http://www.tudou.com/programs/view/" + id + "/", cn_unplug_me_redir, "#html", "", "", "");
   }
   
   
   // GODTUBE
   if (url.indexOf("godtube.com") >= 0 && url.indexOf("godtube.com/flvideo") < 0){
      list[i].url = url.substring(0, url.indexOf(".com/")+5) + "flvideo/" + url.substring(url.indexOf(".com/")+5, url.length);
   }
   
   // BEASTTUBE
   if (url.indexOf("beasttube.com") >= 0 && url.indexOf(".flv") >= 0) {
      list[i].url = "http://vid.beasttube.com/flvideo/" + url.substring(url.indexOf(".com/")+5, url.length);
   }
   
   //ANIMEEPISODES
   if (url.indexOf("animeepisodes.net") >= 0 && url.indexOf("fileid") >= 0) {
      var num = url.substring(url.indexOf("fileid"), url.length);
      num = num.substring(num.lastIndexOf("=")+1, num.length);
      if (num.indexOf("&") >= 0) num = num.substring(0, num.indexOf("&"));
      //cn_unplug_is_player(list[i]);
      if (num.length > 2) {
         //cn_unplug_a(list, ip+"animeepisodes", "http://209.9.228.21/flv2/" + num + "-.flv", cn_unplug_me_flv, "", "", "", "");
         cn_unplug_a(list, ip+"animeepisodes", "http://209.9.234.2/above?fileid=" + num, cn_unplug_me_textplay, "#asx", "", "", "");
      }
   }
   
   if (url.indexOf("glumbert.com") >= 0 && url.indexOf("player.swf") >= 0) {
      cn_unplug_is_player(list[i]);
      if (list[i].flashvars && list[i].flashvars.indexOf("file=") >= 0) {
         var f = list[i].flashvars;
         f = f.substring(f.indexOf("file=")+"file=".length, f.length);
         if (f.indexOf("&") > 0)
            f = f.substring(0, f.indexOf("&"));
         if (f.length > 0)
            cn_unplug_a(list, ip+"glumbert", "http://static.glumbert.com/media/video/flash/" + f  + ".flv", cn_unplug_me_flv, "#flv", "", "", "");
      }
   }
   
   //SHARKLE.COM
   if (url.indexOf("sharkle.com") >= 0){
      var id = cn_unplug_urlget(url, "rnd");
      if (id.length > 0)
         cn_unplug_a(list, ip+"sharkle", "http://www.sharkle.com/inc/misc/about.php?rnd=" + id + "&ssd=ZeleninGalaburda", cn_unplug_me_flv, "#flv", "", "", "");
   }
   
   //LIBERO.IT
   if (url.indexOf("video.libero.it") >= 0 && url.indexOf("id=") >= 0){
      var id = url.substring(url.indexOf("id=") + "id=".length, url.length);
      if (id.indexOf("&") > 0)
         id = id.substring(0, id.indexOf("&"));
      // strim ".flv" from end
      if (id.indexOf(".") > 0)
         id = id.substring(0, id.indexOf("."));
      
      // use "video2" path. Others may also be avaliable
      cn_unplug_a(list, ip+"glumbert", "http://video.libero.it/static/video2/" + id.charAt(0) + "/" + id.charAt(1) + "/" + id.charAt(2) + "/" + id + ".flv", cn_unplug_me_flv, "#flv", "", "", "");
   }
   
   //DAUM
   if (url.indexOf("daum.net/mflvPlayer.swf") > 0) {
      var id = cn_unplug_urlget(url, "vid");
      var base = url.substring(0, url.indexOf(".net/") + ".net".length);
      cn_unplug_a(list, ip+"daum", base+"/viewer/MovieLocation.do?vid="+id, cn_unplug_me_data, "", "", "", "");
   }
   
   //CRUNCHYROLL.COM / ADBRITE
   if (url.indexOf("vid.adbrite.com/video/abplayer.swf") >= 0) {
      var id = cn_unplug_urlget(url, "vid");
      if (id.length > 0)
         cn_unplug_a(list, ip+"adbrite", "http://vid.adbrite.com/player/player_config.php?og=1&fs=0&vid=" + id, cn_unplug_me_data, "", "", "", "");
   }
   
   //GAMEVIDEOS
   if (url.indexOf("gamevideos.com") >= 0 && url.indexOf(".swf") >= 0) {
      cn_unplug_is_player(list[i]);
      var id = cn_unplug_urlget(url, "src");
      if (id.length > 0)
         cn_unplug_a(list, ip+"gamevideos", id, cn_unplug_me_data, "", "", "", "");
   }
   
   //METACAFE EMBED
   if (url.indexOf("metacafe.com/fplayer/") >= 0) {
      cn_unplug_is_player(list[i]);
      
      cn_unplug_a(list, ip+"metacafe-embed", "http://www.metacafe.com/watch/" + url.substring(url.indexOf("fplayer/")+"fplayer/".length, url.indexOf(".swf")) + "/", cn_unplug_me_redir, "", "", list[i].detail, "");
      
      cn_unplug_a(list, ip+"metacafe-embed-xml", "http://www.metacafe.com/fplayer.php?itemID=" + url.substring(url.indexOf("fplayer/")+"fplayer/".length, url.indexOf(".swf")) + "&fs=n&t=embedded", cn_unplug_me_data, "", "", list[i].detail, "");
   }
   
   //WORST PREVIEWS
   if (url.indexOf("tagworld") >= 0 && url.toLowerCase().indexOf("twplayer.swf") >= 0){
      
      cn_unplug_is_player(list[i]);
      if (list[i].flashvars && list[i].flashvars.toLowerCase().indexOf("videourl") >= 0) {
         var v = list[i].flashvars;
         v = v.substring(v.toLowerCase().indexOf("videourl"), v.length) + "&";
         v = v.substring(v.indexOf("=")+1, v.indexOf("&"));
         
         cn_unplug_a(list, ip+"worstpreviews", "http://stream.tagworld.com/" + v, cn_unplug_me_flv, "", "", list[i].detail, "");
      } else {
         list[i].notes = "Stop NoScript from blocking this object for more";
      }
   }
   
   
   //DAILYMOTION BLOG EMBED FIXME

   if (url.indexOf("dailymotion.com/swf") >= 0) {
      //list[i].media_type = cn_unplug_me_data; NOTE bad!!
      list[i].url += " ##head:only";
      if (0) { /* BAD - DELME */
         var u = url;
         if (u.indexOf("?") > 0) u = u.substring(0, u.indexOf("?"));
         if (u.indexOf("#") > 0) u = u.substring(0, u.indexOf("#"));
         u = u.substring(u.lastIndexOf("/")+1, u.length);
         if (u.indexOf("-") > 0) {
            var id = u.substring(0, u.indexOf("-"))
            var key = u.substring(u.indexOf("-")+1, u.length)
            cn_unplug_a(list, ip+"dailymotion-blog", "http://www.dailymotion.com/get/" + 14 + "/" + 320 + "x" + 240 + "/flv/" + id + ".flv?key=" + key, cn_unplug_me_flv, "", "320x240", "", "");
         }
      }
   }
   
   
   // YOUTUBE
   if (doc.URL.indexOf("youtube.com") < 0 ||
       doc.URL.indexOf("youtube.com") > doc.URL.indexOf("?")) { /* NOT youtube */
      var rgyou = /youtube.*(\/v\/|\.swf\?.*id=|\?v=)([A-Za-z0-9_-]*)/ig;
      var rr;
      while (rr = rgyou.exec(url)){
         cn_unplug_is_player(list[i]);
         var id=rr[2];
         if (id.indexOf("FLVPlayer") < 0)
            cn_unplug_a(list, ip+"youtube-redir", "http://www.youtube.com/watch?v=" + id, cn_unplug_me_data, "#xml", "", list[i].detail, "");
      
         /* cn_unplug_a(list, ip+"youtube-dl-v", "http://youtube.com/get_video?video_id=" + id, cn_unplug_me_flv, "#flv", "", list[i].detail, ""); */
      }
   }
   
   // YOUTUBE-DL
   {
      var rgyou = /youtube\.com.*player2\.swf\?(.+)/ig;
      var rr;
      while (rr = rgyou.exec(url)){
         cn_unplug_is_player(list[i]);
         var id=rr[1];
         if (id.indexOf("t=") < 0) {
            cn_unplug_a(list, ip+"youtube-dl-as-redir", "http://www.youtube.com/watch?v=" + id, cn_unplug_me_data, "#xml", "", list[i].detail, "");
         } else {
            cn_unplug_a(list, ip+"youtube-dl", "http://youtube.com/get_video?" + id, cn_unplug_me_flv, "#flv", "", list[i].detail, "");
         }
      }
   }
   
   //MYSPACE (newer version for 9 or 10 digit links)
   if (url.indexOf("myspace.com") >= 0 && url.toLowerCase().indexOf("vplayer.swf") >= 0 && list[i].flashvars){
      var num = list[i].flashvars.substring(list[i].flashvars.toLowerCase().indexOf("m="), list[i].flashvars.length);
      num = num.substring(num.indexOf("=")+1, num.length);
      if (num.indexOf("&") >= 0) num = num.substring(0, num.indexOf("&"));
      if (num.length > 0) {
         var num_nozero = num;
         while (num.length < 12) num = "0"+num;
         var eu = "http://content.movies.myspace.com/" +
            num.substring(0,7) + '/' + num.charAt(11) +
            num.charAt(10) + '/' + num.charAt(9) +
            num.charAt(8) + '/' + num_nozero + '.flv';
         cn_unplug_a(list, ip+"myspace-any", eu, cn_unplug_me_flv, "", "", "", "");
      }
      cn_unplug_is_player(list[i]);
   }
   
   // VIMEO
   if (url.indexOf("vimeo.com") >= 0 && url.indexOf("clip") >= 0){
      var id = url.substring(url.indexOf("clip")+"clip".length, url.length);
      if (id.indexOf(":") >= 0)
         id = id.substring(id.indexOf(":")+1, id.length)
      else if (id.indexOf("=") >= 0)
         id = id.substring(id.indexOf("=")+1, id.length)
      if (id.indexOf("/") >= 0)
         id = id.substring(0, id.indexOf("/"))
      if (id.indexOf("?") >= 0)
         id = id.substring(0, id.indexOf("?"))
      if (id.indexOf("#") >= 0)
         id = id.substring(0, id.indexOf("#"))
      if (id.indexOf("&") >= 0)
         id = id.substring(0, id.indexOf("&"))
      if (id.length > 0)
         cn_unplug_a(list, ip+"vimeo", "http://www.vimeo.com/_moogaloop/vimeo.ml.get_clip_details.php?clip_id=" + id + "&width=400&height=300", cn_unplug_me_data, "#xml", "", "", "");
   }
   
   // MYVIDEO.DE EMBED
   if (url.indexOf("myvideo.de/movie/") >= 0) {
      var id = url.substring(url.indexOf("myvideo.de/movie/") + "myvideo.de/movie/".length, url.length);
      id = cn_unplug_mainurl(id);
      if (id.length > 0)
         cn_unplug_a(list, ip+"myvideo.de-embed", "http://www.myvideo.de/watch/" + id, cn_unplug_me_redir, "", "", "", "");
   }
   
   //Google Embedded
   if (url.indexOf("googleplayer.swf") >= 0 && doc.URL.indexOf("google.") < 0){
      var u2 = url + "&";
      var regx = /(google[\w\.]*)\/.*googleplayer\.swf?.*docid=([^&]*)&/ig;
      var regxr;
      cn_unplug_is_player(list[i]);
      if (regxr = regx.exec(u2)){
         cn_unplug_a(list, ip+"google_embed-redir", "http://video." + regxr[1] + "/videoplay?docid=" + regxr[2], cn_unplug_me_redir, "#xml", "", list[i].detail, "");
      }
   }
   
   //DUMPALINK
/* FIXME downloads SWF file
   if (url.indexOf("www.dumpalink.com/playvideo.php") > 0) {
      list[i].media_type = cn_unplug_me_data;
   } */
   
   //EVIDEOSHARE
   if (url.indexOf("evideoshare.com") >= 0 && url.indexOf("file=") >= 0 && url.indexOf(".swf") >= 0){
      cn_unplug_a(list, ip+"evideoshare", url.substring(url.indexOf("file=")+"file=".length, url.length), cn_unplug_me_media, "", "", list[i].detail, "");
   }
   
   //GENERIC STRING
   {
      /* match ?http:// etc */
      var reg = /\?[a-zA-Z]\:{1,8}\/\//
      var rr;
      while (rr = reg.exec(url) ){
         cn_unplug_a(list, ip+"generic-fullsearchstring", url.substring(url.indexOf("?")+1, url.length), cn_unplug_me_unknown, "", "", list[i].detail, "");
      }
   }
   
   //GENERIC URL
   // widened to accept "?..." or "...&...." or "...=..."
   if (url.indexOf("?") >= 0 || url.indexOf("&") >= 0 || url.indexOf("=") >= 0){
      //has ?... search part of url
      var ser = url + "&";
      if (ser.indexOf("?") >= 0) {
         // eg: http://w3.org/dir?flash=flash.flv
         // variables in GET
         ser = ser.substring(ser.indexOf("?")+1, ser.length);
      } else {
         // eg: http://w3.org/dir/flash=flash.flv
         // variables after final slash
         var a = "";
         if (ser.indexOf("=") >= 0)
            a = ser.substring(0, ser.indexOf("="));
         else if (ser.indexOf("&") >= 0)
            a = ser.substring(0, ser.indexOf("&"));
         ser = ser.substring(a.lastIndexOf("/")+1, ser.length);
      }
      //parse variable pairs
      while (ser.indexOf("&") >= 0){
         //foreach search option:
         var g = ser.substring(0, ser.indexOf("&"));
         g = g.substring(g.indexOf("=")+1, g.length);
         if (g.indexOf(".flv") >= 0 || g.indexOf("//") >= 0){
            //url in search string
            
            var u1;
            
            // match relative to document url
            u1 = cn_unplug_url(doc, g);
            cn_unplug_a(list, ip+"generic-searchstring", u1, cn_unplug_me_noscore, "", cn_unplug_s("Guessed.Location"), list[i].detail, "");
            
            // match relative to base of url
            u1 = cn_unplug_url2(url.substring(0,url.indexOf("?")), g);
            cn_unplug_a(list, ip+"generic-searchstring-samelocation", u1, cn_unplug_me_unknown, "", cn_unplug_s("Guessed.Location"), list[i].detail, "");
            
/* NOTE dosen't work well
         } else if (g.indexOf(".xml") >= 0){
            //xml url in search string
            g = cn_unplug_url(doc, g);
            cn_unplug_a(list, ip+"generic-searchstring", g, cn_unplug_me_textplay, "", cn_unplug_s("Guessed.Location"), list[i].detail, "");
*/
         }
         ser = ser.substring(ser.indexOf("&")+1, ser.length);
      }
   }
   
   //really a ./ of swf location - fixme
   if (url.indexOf("vault.brawl-hall.com")>=0){
      cn_unplug_is_player(list[i]);
      cn_unplug_a(list, ip+"flv", "http://vault.brawl-hall.com/" + url.substring(url.lastIndexOf("./")+1, url.length), cn_unplug_me_flv, "#flv", "", list[i].detail, "");
   }
   
   //generic url: flash
   if (list[i].flashvars && list[i].flashvars != ""){
      //has ?... search part of url
      var ser = list[i].flashvars + "&";
      while (ser.indexOf("&") >= 0){
         //foreach search option:
         var g = ser.substring(0, ser.indexOf("&"));
         if (
            g.indexOf(".flv") >= 0
         || g.indexOf("//") >= 0
         || g.indexOf("url=") >= 0
         || g.indexOf("playlist") >= 0
         || g.indexOf("Playlist") >= 0
         ){
            var mt = cn_unplug_me_unknown;
            
            if (g.indexOf("laylist") >= 0)
               mt = cn_unplug_me_data;
            
            
            // value part
            g = g.substring(g.indexOf("=")+1, g.length);
            
            //url in search string
            if (g.indexOf(".htm") < 0 && g.charAt(g.length - 1) != "/" /* homepage */){
               // media
               if (g.indexOf("./") == 0) g = g.substring(2, g.length);
               
               var g1 = cn_unplug_url(doc, g);
               cn_unplug_a(list, ip+"generic-flashvar{" + list[i].flashvars + "}", g1, mt, "", "Possible Location from Embedded Media", list[i].detail, "");
               
               var g2 = cn_unplug_url2(list[i].url, g);
               if (g2 != g){
                  cn_unplug_a(list, ip+"generic-flashvar2{" + list[i].flashvars + "}", g2, mt, "", "Alterative Possible Location from Embedded Media", list[i].detail, "");
               }
            }
         }
         ser = ser.substring(ser.indexOf("&")+1, ser.length);
      }
   }
}

/*************** JAVA ****************/


function cn_unplug_javastar(doc, els, list){
   var j2 = els.innerHTML.split(/\n/);
   for (var i = 0; i < j2.length; i++){
      cn_unplug_javasoup(doc, j2[i], list)
   }
   
   /* ** inhtml ** */
   var jam = els.innerHTML;
   
   var url = String(doc.URL);
   
   //GENERIC "new FlashObject(" or GetFlashPlayer
   // Supports sites: livevideo.com (GetFlashPlayer)
   {
      var newflashrx = /(FlashObject|GetFlashPlayer)[\s]*\(["']([^"']+)["'][\s]*,/ig;
      var newflash_r;
      while (newflash_r = newflashrx.exec(jam)){
          cn_unplug_a(list, "javastar.flashobject", cn_unplug_url(doc, newflash_r[2]), cn_unplug_me_flvplay, "", "", "", "");
      }
   }
   
   //DOWNLOAD.COM
   if (doc.URL.indexOf("video.download.com/")>=0){
      if (jam.indexOf("plylst=")>=0 && jam.indexOf("ids=")>=0){
         var ur = jam.substring(jam.indexOf("plylst="), jam.length);
         ur = ur.substring(ur.indexOf("\"")+1, ur.length);
         ur = ur.substring(0, ur.indexOf("\""));
         var id = jam.substring(jam.indexOf("ids="), jam.length);
         id = id.substring(id.indexOf("\"")+1, id.length);
         id = id.substring(0, id.indexOf("\""));
         cn_unplug_a(list, "javasoup.downloadcom", cn_unplug_url(doc, ur + "?id=" + id), cn_unplug_me_textplay, "", "", "", "");
      }
   }
   
   //GRINDTV
   if (doc.URL.indexOf("grindtv.com/video") > 0) {
      var rx = /current_videoID\s*=\s*['"]?([0-9]*)['"]?;.*category_id\s*=\s*['"]?([0-9]*)['"]?;/gi;
      var rr;
      while (rr = rx.exec(jam)) {
         var id = rr[1];
         var cat = rr[2];
         var iz = "000000000" + id;
         cn_unplug_a(list, "javasoup.grindtv", "http://videos.grindtv.com/" + cat + "/" + iz.substring(iz.length-8, iz.length-6) + "/" + iz.substring(iz.length-6, iz.length-4) + "/" + iz.substring(iz.length-4, iz.length-2) + "/" + iz.substring(iz.length-2, iz.length) + "/" + id + ".flv", cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   
   //YOUTUBE
   if (doc.URL.indexOf("youtube") >= 0){
      // match ANY video_id= and t= in java to construct phrase
       var reg = /video_id=(.*?)&.*t=(.*?)[&"]/g;
       var rr;
       while (rr = reg.exec(jam)){
          cn_unplug_a(list, "javasoup.youtube-old-scan", cn_unplug_url(doc, "http://youtube.com/get_video?video_id=" + rr[1] + "&t=" + rr[2]), cn_unplug_me_flv, "", "", "", "");
       }
       
       var reg = /player2\.swf\?([^"]+)"/ig;
       while (rr = reg.exec(jam)){
         var id = rr[1];
         if (id.indexOf("t=") < 0) {
            cn_unplug_a(list, "javasoup.youtube-dl-as-redir", "http://www.youtube.com/watch?v=" + id, cn_unplug_me_data, "#xml", "", "", "");
         } else {
            cn_unplug_a(list, "javasoup.youtube-dl", "http://youtube.com/get_video?" + id, cn_unplug_me_flv, "#flv", "", "", "");
         }
      }
   }
   
   
   //MILITARY.COM
   if (url.indexOf("military.com") > 0) {
      var reg = /myMoviePath[\s]*=[\s]*\"([^\"]*)\"/gi;
      var rr;
      while (rr = reg.exec(jam)) {
         cn_unplug_a(list, "javasoup.military", "http://" + rr[1] + "_high.flv", cn_unplug_me_flv, "#flv", "", "", "");
      }
   }
   
   
   //GENERIC, FLASHVIDEOTHEATER
   {
      var reg = /[\"\']Filename[\"\'],\s*[\"\']([^\"\']+)[\"\']/gi;
      var rr;
      while (rr = reg.exec(jam)) {
         cn_unplug_a(list, "javasoup.filename-grab", cn_unplug_url2(url, rr[1]), cn_unplug_me_unknown, "", "", "", "");
      }
   }
   
   
   // GENERIC, QUOTED FLV
   if (false) {
      var reg = /[\"\']([^\"\']*\.flv[^\"\']*)[\"\']/gi;
      var rr;
      while (rr = reg.exec(jam)) {
         var l = rr[1];
         cn_unplug_a(list, "javasoup.quoted-flv", cn_unplug_url2(url, l), cn_unplug_me_unknown, "", "", "", "");
      }
   }
   
   
   // IMEEM.COM
   if (url.indexOf("imeem.com") >= 0) {
      var reg = /\\u003d([^\\\"\']*\.flv[^\\\"\']*)\\u0026/gi;
      var rr;
      while (rr = reg.exec(jam)) {
         cn_unplug_a(list, "javasoup.imeem", cn_unplug_url2(url, rr[1]), cn_unplug_me_unknown, "", "", "", "");
      }
   }
   
   
   // ADULTVIDEOPLAYER.COM
   if (jam.indexOf("adultvideoplayer.com/main.php") >= 0){
      var u = jam;
      var reg = /\?(?:.*&)?MODE=PLAY&(?:.*&)?(?:VIDEO)?ID=([0-9A-F]+)&(?:.*&)?SESSIONID=([0-9A-F]+)/ig;
      var rr;
      if (rr = reg.exec(u)) {
         cn_unplug_a(list, "javasoup.adultvp", cn_unplug_url2(doc.URL, "stream-flv.php?ID=" + rr[1] + "&SESSIONID=" + rr[2]), cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   if (doc.URL.indexOf("bravotv.com") >= 0){
     var reg = /pathToASX\s*=\s*['"]([^"']*)['"].*content\s*=\s*['"]([^"']*)['"]/ig;
     var rr;
     while (rr = reg.exec(jam)){
       cn_unplug_a(list, "javasoup.bravotv", cn_unplug_url(doc, rr[1] + rr[2] + ".asx"), cn_unplug_me_textplay, "", "", "", "");
     }
  }
  
  
   // ABC NEWS ( GO.COM )
   if (url.indexOf("go.com") >= 0) {
      var reg = /qscatId=\"([^\"]*)\"/gi;
      var rr;
      while (rr = reg.exec(jam)){
         cn_unplug_a(list, "javasoup.go", cn_unplug_url2(url, "/Video/fspXML?catId=" + rr[1]), cn_unplug_me_data, "", "", "", "");
      }
   }
   
   
   //IMEEM.COM MUSIC
   if (url.indexOf("imeem.com") >= 0 && url.indexOf("music/") >= 0) {
      var reg = /contentKey\s*\:\s*["']([^"']*)["']/gi;
      var rr;
      while (rr = reg.exec(jam)){
         var id = rr[1];
         var u2 = "post://www.imeem.com/amf/" + " ##b:nary" + " ##type:" + escape("application/x-amf");
         cn_unplug_a(list, "javasoup.imeem-amf", u2, cn_unplug_me_data, "", "", "", "");
         list[list.length-1].postdata = unplug_hexstring("00 00 00 01 00")
            + unplug_hexstring("13") + "imeem.GetStreamInfo" + unplug_hexstring("00")
            + unplug_hexstring("02") + "/1" + unplug_hexstring("00")
            + unplug_hexstring("00 00 1e 0a 00 00 00 01 03 00 01 65 01 00 00 01 6b 02 00")
            + unplug_hexstring("0a") + id + unplug_hexstring("00")
            + unplug_hexstring("00 09");
      }
   }
   
  // GOOGLE VIDEO AS OF JULY 06
  if (doc.URL.indexOf("video.google.com") >= 0 || 1 != 2){
      var reg = /videoUrl(?:=|\\u003d)([^&]*)&/ig
      var rr;
      if (rr = reg.exec(jam)) {
         var ember = rr[1];
         cn_unplug_a(list, "javasoup.googlevideo003d", cn_unplug_url(doc, unescape(ember)), cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   
   // PEEKVID
   if (url.indexOf("peekvid.com") >= 0){
      var reg = /flashvars\:\s*[\"\'](?:[^\"\']*[\&])?(?:file|url)=([^\"\'&]*)[\"\'&]/gi;
      var rr;
      if (rr = reg.exec(jam)) {
         var ux = unescape(rr[1]);
         if (ux.indexOf("//") < 0)
            ux = "http://www.peekvid.com/client/include/" + ux;
         cn_unplug_a(list, "javasoup.peekvid", ux, cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   
   // BREAK.COM
   if (doc.URL.indexOf("break.com") >= 0) {
      var rname = /sGlobalFileName[\s]*=[\s]*['"]([^'"]*)['"]/i;
      var rpath = /sGlobalContentFilePath[\s]*=[\s]*['"]([^'"]*)['"]/i;
      
      if (rname.test(jam) && rpath.test(jam)) {
         var xname = rname.exec(jam)[1];
         var xpath = rpath.exec(jam)[1];
         
         cn_unplug_a(list, "javasoup.break", "http://media1.break.com/dnet/media/" + xpath + "/" + xname + ".flv", cn_unplug_me_flv, "", "", "", "");
      }
   }
   
   
   // TODO YOUVIDZ.COM
   if (url.indexOf("youvidz.com") >= 0) {
      var reg = /file=([0-9]+)\.flv/gi;
      var rr;
      
      while (rr = reg.exec(jam)){
         var id = rr[1];
         
         var code = "084tgr676aafjhg8f4"; // NOTE - dunno what this is
         cn_unplug_a(list, "javasoup.youvidz", "http://www.youvidz.com/" + code + "/" + id + ".flv", cn_unplug_me_flv, "", "", "", "");
         
         var code = "09e714c0774e22cb806f"; // HIGH RES?
         cn_unplug_a(list, "javasoup.youvidz", "http://www.youvidz.com/" + code + "/" + id + ".flv", cn_unplug_me_flv, "", "Fullscreen", "", "");
      }
   }
   
   
   // GROUPER.COM
   if (url.indexOf("grouper.com") >= 0) {
      var reg = /vmtu=([^"']*?)_tnm.jpg/gi
      var rr;
      while (rr = reg.exec(jam)){
         var id = unescape(rr[1]);
         cn_unplug_a(list, "javasoup.grouper", id + "_preview.flv", cn_unplug_me_flv, "", "Preview", "", "");
      }
   }
   
   
   // QUOTED FLASH
   {
      var reg = /\=\s*["']([^"']*\.(?:flv|swf)[^"']*)["']/gi;
      var rr;
      while (rr = reg.exec(jam)){
         cn_unplug_a(list, "javasoup.quote-flash", rr[1], cn_unplug_me_swf, "", "", "", "");
      }
   }
   
   
   //SWF OBJECT
   {
      var reg = /SWFObject\s*\(["']([^"']*)["']\s*[,\)]/gi;
      var reg2 = /addParam\s*\(["']flashvars["']\s*,\s*["']([^"']*)["']\s*\)/gi;
      var rr;
      var flashvar = "";
      if (rr = reg2.exec(jam)){
         flashvar = rr[1];
      }
      while (rr = reg.exec(jam)){
         cn_unplug_a(list, "javasoup.SWFObject", rr[1], cn_unplug_me_swf, "", "", "", flashvar);
      }
   }
   
   //SWF OBJECT 2
   {
      var reg = /\{[^\}]*movie\s*\:\s*[\"\']([^\"\']*)[\"\'][^\}]*flashvars\s*\:\s*[\"\']([^\"\']*)[\"\']/gi;
      var rr;
      while (rr = reg.exec(jam)){
         cn_unplug_a(list, "javasoup.SWFObject2", rr[1], cn_unplug_me_swf, "", "", "", rr[2]);
      }
   }
   
   //SWF OBJECT XML
   {
      var reg = /xml\s*\:\s*[\"\']([^\"\'\<\>]*)[\"\']/gi;
      var rr;
      while (rr = reg.exec(jam)){
         cn_unplug_a(list, "javasoup.SWFObject-xml", rr[1], cn_unplug_me_data, "", "", "", "");
      }
   }
   
   // TUDOU.COM
   if (url.indexOf("tudou.com") >= 0){
      var reg = /iid[\s]*\=[\s]*([0-9]+)/gi;
      var rr;
      while (rr = reg.exec(jam)) {
         var n = rr[1];
      
         cn_unplug_a(list, "javasoup.tudou", "post://www.tudou.com/player/cdn.php ##form:" + escape("r=0&id=" + n), cn_unplug_me_data, "", "", "", "");
      }
   }

}

function cn_unplug_javasoup(doc, jam, list){
   /* line by line */
   /* depreciate? */
   //GENERIC
   if (jam.indexOf("var url") >= 0 && doc.URL.indexOf("livevideo.com") < 0) {
      var c = "";
      jam = jam.substring(jam.indexOf("var url")+7, jam.length);
      if (jam.indexOf("\"") < 6) c = "\"";
      else if (jam.indexOf("\'") < 6) c = "\'";
      if (c != ""){
         jam = jam.substring(jam.indexOf(c)+1, jam.length);
         if (jam.indexOf(c) > 0) {
            jam = jam.substring(0, jam.indexOf(c));
         
            cn_unplug_a(list, "javasoup.generic-var-url", cn_unplug_url(doc, jam), cn_unplug_me_unknown, "", "", "", "");
         }
      }
   }
   
   //GENERIC FLV URL
   {
      var reg = /["']([^"'\/=]*:\/\/[^"']*\.flv[^"']*)["']/ig;
      var regr;
      while (regr = reg.exec(jam)) {
         var u = regr[1];
         
         if (u.indexOf("secure.ifilm.com") > 0)
            u = u.replace("|", "&");
         
         cn_unplug_a(list, "javasoup.generic-flv", u,
            ( doc.URL.indexOf("grouper.com") >= 0
            || u.indexOf("?") < u.indexOf(".flv")
            || u.indexOf(".swf") >= 0 )
               ? cn_unplug_me_unknown
               : cn_unplug_me_flv,
            "", "", "", "");
     }
   }
   
   //DAILYMOTION
   if (doc.URL.indexOf("dailymotion") >= 0){
      if (jam.indexOf("url=") >= 0){
         jam = jam.substring(jam.indexOf("url=")+4, jam.length);
         jam = jam.substring(0, jam.indexOf("&"));
         cn_unplug_a(list, "javasoup.dailymotion", unescape(jam), cn_unplug_me_flv, "", "", "", "");
      }
   }
}

